<?php
declare(strict_types=1);

namespace Inti\Media;

use Inti\Provider\Service\ProviderManager;
use Inti\Wp\Plugin\Service\PluginManager;

/**
 * Class ConfigProvider
 *
 * @package Inti\Media
 * @author Danijel Fabijan <hipnaba@gmail.com>
 * @link https://bitbucket.org/oktan-nautika/inti-media
 */
final class ConfigProvider
{
    /**
     * @return array
     */
    public function __invoke(): array
    {
        return [
            'media' => [
                Service\ImageManager::class => [
                    'root' => 'public/media',
                ],
            ],

            'routes' => [[
                'name' => 'media.serve',
                'path' => '/media/{path:.+}',
                'middleware' => Handler\Serve::class,
                'allowed_methods' => ['HEAD', 'GET'],
            ], [
                'name' => 'media.upload',
                'path' => '/media/{path:.+}',
                'middleware' => Handler\Upload::class,
                'allowed_methods' => ['PUT', 'POST'],
            ]],

            'dependencies' => [
                'factories' => [
                    'ImageMetadataCache' => Container\ImageMetadataCacheFactory::class,
                    Handler\Serve::class => Handler\HandlerFactory::class,
                    Handler\Upload::class => Handler\HandlerFactory::class,
                    Service\ImageManager::class => Container\ImageManagerFactory::class,
                ],
            ],

            'wp' => [
                'plugins' => [
                    Plugin\MediaHandler::class,
                ],
            ],

            PluginManager::class => [
                'factories' => [
                    Plugin\MediaHandler::class => Plugin\MediaHandlerFactory::class,
                ],
            ],

            ProviderManager::class => [
                'registered' => [
                    Provider\ImageProvider::class,
                ],
                'factories' => [
                    Provider\ImageProvider::class => Provider\ImageProviderFactory::class,
                ],
            ],
        ];
    }
}
